import React from 'react';
import { Button } from '../../components';
import { Accordion, AccordionBody, AccordionHead, AccordionItem } from '../../components/accordion';

export type MonitorType = 'report' | 'alert';

type SidebarProps = {
  reports: string[];
  alerts: string[];
  changeActive: (category: MonitorType, val: string) => void;
  setAdding: (val: boolean) => void;
  setActiveCategory: (val: MonitorType | undefined) => void;
};

export function Sidebar(props: SidebarProps) {
  return (
    <div className="w-1/4 border-r overflow-auto flex flex-col h-full">
      <span className="text-lg text-secondary-700 font-semibold px-2 py-4">Insight Sharing</span>
      <Accordion defaultOpenIndex={0}>
        <AccordionItem className="">
          <AccordionHead className="border-b bg-secondary-50 hover:bg-secondary-100 p-1">
            <div className="w-full flex justify-between">
              <span className="font-semibold">Reports</span>
              <div
                onClick={(e) => {
                  props.setAdding(true);
                  props.setActiveCategory('report');
                  e.stopPropagation();
                }}
              >
                <Button
                  as={'a'}
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--outline-add]"
                  onClick={() => {}}
                />
              </div>
            </div>
          </AccordionHead>
          <AccordionBody className="ml-0">
            <ul className="space-y-2">
              {props.reports.map((name, index) => (
                <li
                  key={index}
                  className="cursor-pointer p-2 hover:bg-secondary-50"
                  onClick={() => {
                    props.changeActive('report', name);
                    props.setAdding(false);
                  }}
                >
                  {name}
                </li>
              ))}
            </ul>
          </AccordionBody>
        </AccordionItem>
        <AccordionItem>
          <AccordionHead className="border-b bg-secondary-50 hover:bg-secondary-100 p-1">
            <div className="w-full flex justify-between">
              <span className="font-semibold">Alerts</span>
              <div
                onClick={(e) => {
                  props.setAdding(true);
                  props.setActiveCategory('alert');
                  e.stopPropagation();
                }}
              >
                <Button
                  as={'a'}
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--outline-add]"
                  onClick={() => {}}
                />
              </div>
            </div>
          </AccordionHead>
          <AccordionBody className="ml-0">
            <ul className="space-y-2">
              {props.alerts.map((name, index) => (
                <li
                  key={index}
                  className="cursor-pointer p-2 hover:bg-secondary-50"
                  onClick={() => {
                    props.changeActive('alert', name);
                    props.setAdding(false);
                  }}
                >
                  {name}
                </li>
              ))}
            </ul>
          </AccordionBody>
        </AccordionItem>
      </Accordion>
    </div>
  );
}
