import { describe, it, expect } from 'vitest';
import { getNodeLabel, getEdgeType } from '../utils/getNodeOrEdgeType';
import { GraphQueryResultFromBackend } from '../../data-access/store/graphQueryResultSlice';

describe('getNodeLabel', () => {
  it('should return node type based on _id', () => {
    const node: GraphQueryResultFromBackend['nodes'][number] = {
      _id: 'Person/123',
      attributes: {},
    };
    const label = getNodeLabel(node);
    expect(label).toBe('Person');
  });

  it('should return node label if present', () => {
    const node: GraphQueryResultFromBackend['nodes'][number] = {
      _id: 'Person/123',
      label: 'Student',
      attributes: {},
    };
    const label = getNodeLabel(node);
    expect(label).toBe('Student');
  });

  it('should return first label from attributes if labels array is present', () => {
    const node: GraphQueryResultFromBackend['nodes'][number] = {
      _id: 'Person/123',
      attributes: { labels: ['Teacher', 'Mentor'] },
    };
    const label = getNodeLabel(node);
    expect(label).toBe('Teacher');
  });

  it('should return _id-based node type if labels array is empty', () => {
    const node: GraphQueryResultFromBackend['nodes'][number] = {
      _id: 'Person/123',
      attributes: { labels: [] },
    };
    const label = getNodeLabel(node);
    expect(label).toBe('Person');
  });
});

describe('getEdgeType', () => {
  it('should return edge type based on _id', () => {
    const edge: GraphQueryResultFromBackend['edges'][number] = {
      _id: 'Relationship/456',
      attributes: {},
      from: 'Person/123',
      to: 'Person/456',
    };
    const edgeType = getEdgeType(edge);
    expect(edgeType).toBe('Relationship');
  });

  it('should return edge type from attributes if _id does not contain /', () => {
    const edge: GraphQueryResultFromBackend['edges'][number] = {
      _id: '456',
      attributes: { Type: 'FRIENDS_WITH' },
      from: 'Person/123',
      to: 'Person/456',
    };
    const edgeType = getEdgeType(edge);
    expect(edgeType).toBe('FRIENDS_WITH');
  });
});
